factorize

Function factorize 

pub fn factorize(
    lu: &mut LU,
    b_begin: &[usize],
    b_end: &[usize],
    b_i: &[usize],
    b_x: &[f64],
    c0ntinue: bool,
) -> Status
Factorize the matrix B into its LU factors. Choose pivot elements by a Markowitz criterion subject to columnwise threshold pivoting (the pivot may not be smaller than a factor of the largest entry in its column).

Arguments

Matrix B must be in packed column form. b_i and b_x are arrays of row indices and nonzero values. Column j of matrix B contains elements

    b_i[b_begin[j] .. b_end[j]-1], b_x[b_begin[j] .. b_end[j]-1].

The columns must not contain duplicate row indices. The arrays b_begin and b_end may overlap, so that it is valid to pass b_p, b_p[1..] for a matrix stored in compressed column form (b_p, b_i, b_x).

c0ntinue: false to start a new factorization; true to continue a factorization after reallocation.