LUInt

Type Alias LUInt 

pub type LUInt = i64;
BLU integer type

All integers in BLU code are of type lu_int, which must be a signed integer type. It is required that all integer values arising in the computation can be stored in double variables and converted back to lu_int without altering their value.

LU_INT_MAX must be the maximum value of a variable of type lu_int.

The default is 64 bit integers to make the code easily callable from Julia. int64_t is optional in the C99 standard, but available on most systems.